"""
# -*- coding: utf-8 -*-
#===============================================================================
#
# Copyright (C) 2013/2014 Laurent Champagnac
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
#===============================================================================
"""

# Logger
from abc import ABCMeta, abstractmethod
import logging
from pythonsol.SolBase import SolBase

SolBase.loggingInit()
logger = logging.getLogger("TcpServerClientContextAbstractFactory")


class TcpServerClientContextAbstractFactory(object):
    """
    ..  py:class:: TcpServerClientContextAbstractFactory()

    Abstract client context factory.
    """
    __metaclass__ = ABCMeta

    #noinspection PyUnusedLocal
    @abstractmethod
    def getNewClientContext(self, tcpServer, clientId, clientSocket, clientAddr):
        """
        ..  py:function:: getNewClientContext(tcpServer, clientId, clientSocket, clientAddr)

        Return a new client context instance.

        :param tcpServer: The TcpServer instance.
        :param clientId: an integer, which is the unique id of this client.
        :param clientSocket: The server socket.
        :param clientAddr: The remote addr information.
        :return Returned object MUST be a subclass of TcpServerClientContext.
        """
        raise Exception("getNewClientContext : this MUST be implemented")
